summaryrefslogtreecommitdiffstats
path: root/src/com/mbien/opencl/CLProgram.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/mbien/opencl/CLProgram.java')
-rw-r--r--src/com/mbien/opencl/CLProgram.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/com/mbien/opencl/CLProgram.java b/src/com/mbien/opencl/CLProgram.java
index 562df69b..44e747bf 100644
--- a/src/com/mbien/opencl/CLProgram.java
+++ b/src/com/mbien/opencl/CLProgram.java
@@ -247,10 +247,10 @@ public class CLProgram extends CLObject implements CLResource {
}
/**
* Prepares the build for this program by returning a {@link CLProgramBuilder}.
*/
- public CLProgramBuilder prepare() {
- return new CLProgramBuilder(this);
+ public CLProgramConfiguration prepare() {
+ return CLProgramBuilder.createForProgram(this);
}
/**
@@ -247,10 +247,10 @@ public class CLProgram extends CLObject implements CLResource {
}
/**
- * Prepares the build for this program by returning a {@link CLProgramBuilder}.
+ * Prepares the build for this program by returning a new {@link CLProgramConfiguration}.
*/